
<!---
FrozenIsBool True
-->

##Example

We can have also set with the a #get in the SettingValueVariable.
Also if the SettingValueVariable is a dict with a #get it is going with priority get
with this key and set with that.